summaryrefslogtreecommitdiffstats
path: root/kviewshell
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
commit3c5631f74d1c75204f950140331e10f739082ee9 (patch)
treea2811ff6c81d3c771745cde47734e65b1da3d806 /kviewshell
parent6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef (diff)
downloadtdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.tar.gz
tdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kviewshell')
-rw-r--r--kviewshell/kmultipage.cpp8
-rw-r--r--kviewshell/kmultipage.h10
-rw-r--r--kviewshell/kviewpart.cpp10
-rw-r--r--kviewshell/kviewpart.h4
-rw-r--r--kviewshell/kviewshell.cpp10
-rw-r--r--kviewshell/kviewshell.h8
6 files changed, 25 insertions, 25 deletions
diff --git a/kviewshell/kmultipage.h b/kviewshell/kmultipage.h
index d6194cc0..8dbd8247 100644
--- a/kviewshell/kmultipage.h
+++ b/kviewshell/kmultipage.h
@@ -14,7 +14,7 @@
class Anchor;
class DocumentWidget;
-class KConfigDialog;
+class TDEConfigDialog;
class KPrintDialogPage_PageOptions;
class KPrinter;
class PageView;
@@ -271,14 +271,14 @@ public:
This method can be re-implemented to add documenttype specific
configuration pages to the central preferences dialog. The
- documentation to KConfigDialog explains how to do that.
+ documentation to TDEConfigDialog explains how to do that.
The default implementation does nothing.
- @param configDialog a pointer to the KConfigDialog the dialog to
+ @param configDialog a pointer to the TDEConfigDialog the dialog to
add pages to
*/
- virtual void addConfigDialogs(KConfigDialog* configDialog) { Q_UNUSED(configDialog); }
+ virtual void addConfigDialogs(TDEConfigDialog* configDialog) { Q_UNUSED(configDialog); }
/* These methods calculate the Zoomfactor needed to fit the pages
@@ -440,7 +440,7 @@ public slots:
virtual void slotShowThumbnails(bool);
/* Used internally. */
- void slotIOJobFinished ( KIO::Job *job );
+ void slotIOJobFinished ( TDEIO::Job *job );
/* Switches to fullscreen mode and back. */
virtual void slotSetFullPage(bool fullpage);
diff --git a/kviewshell/kviewpart.cpp b/kviewshell/kviewpart.cpp
index c09ebeb8..847a8ff8 100644
--- a/kviewshell/kviewpart.cpp
+++ b/kviewshell/kviewpart.cpp
@@ -370,7 +370,7 @@ void KViewPart::initializeMultiPage()
connect( this, TQT_SIGNAL(scrollbarStatusChanged(bool)), multiPage, TQT_SLOT(slotShowScrollbars(bool)));
connect( multiPage, TQT_SIGNAL(pageInfo(int, int)), this, TQT_SLOT(pageInfo(int, int)) );
connect( multiPage, TQT_SIGNAL(askingToCheckActions()), this, TQT_SLOT(checkActions()) );
- connect( multiPage, TQT_SIGNAL( started( KIO::Job * ) ), this, TQT_SIGNAL( started( KIO::Job * ) ) );
+ connect( multiPage, TQT_SIGNAL( started( TDEIO::Job * ) ), this, TQT_SIGNAL( started( TDEIO::Job * ) ) );
connect( multiPage, TQT_SIGNAL( completed() ), this, TQT_SIGNAL( completed() ) );
connect( multiPage, TQT_SIGNAL( canceled( const TQString & ) ), this, TQT_SIGNAL( canceled( const TQString & ) ) );
connect( multiPage, TQT_SIGNAL( setStatusBarText( const TQString& ) ), this, TQT_SLOT( setStatusBarTextFromMultiPage( const TQString& ) ) );
@@ -441,7 +441,7 @@ void KViewPart::restoreDocument(const KURL &url, int page)
}
-void KViewPart::saveDocumentRestoreInfo(KConfig* config)
+void KViewPart::saveDocumentRestoreInfo(TDEConfig* config)
{
config->writePathEntry("URL", url().url());
if (multiPage->numberOfPages() > 0)
@@ -793,7 +793,7 @@ bool KViewPart::openFile()
writeSettings();
// Delete old config dialog
- KConfigDialog* configDialog = KConfigDialog::exists("kviewshell_config");
+ TDEConfigDialog* configDialog = TDEConfigDialog::exists("kviewshell_config");
delete configDialog;
KMultiPage* oldMultiPage = multiPage;
@@ -1447,10 +1447,10 @@ void KViewPart::aboutKViewShell()
void KViewPart::doSettings()
{
- if (KConfigDialog::showDialog("kviewshell_config"))
+ if (TDEConfigDialog::showDialog("kviewshell_config"))
return;
- KConfigDialog* configDialog = new KConfigDialog(mainWidget, "kviewshell_config", KVSPrefs::self());
+ TDEConfigDialog* configDialog = new TDEConfigDialog(mainWidget, "kviewshell_config", KVSPrefs::self());
optionDialogGUIWidget_base* guiWidget = new optionDialogGUIWidget_base(mainWidget);
configDialog->addPage(guiWidget, i18n("User Interface"), "view_choose");
diff --git a/kviewshell/kviewpart.h b/kviewshell/kviewpart.h
index 80c427c5..1ea8aafd 100644
--- a/kviewshell/kviewpart.h
+++ b/kviewshell/kviewpart.h
@@ -13,7 +13,7 @@ class TDEAboutData;
class KAboutDialog;
class KAccel;
class KAction;
-class KConfig;
+class TDEConfig;
class KDirWatch;
class TDEInstance;
class KMultiPage;
@@ -75,7 +75,7 @@ public slots:
void reload();
void restoreDocument(const KURL &url, int page);
- void saveDocumentRestoreInfo(KConfig* config);
+ void saveDocumentRestoreInfo(TDEConfig* config);
protected slots:
void slotShowSidebar();
diff --git a/kviewshell/kviewshell.cpp b/kviewshell/kviewshell.cpp
index e9ffba38..26f1e20b 100644
--- a/kviewshell/kviewshell.cpp
+++ b/kviewshell/kviewshell.cpp
@@ -99,7 +99,7 @@ KViewShell::KViewShell(const TQString& defaultMimeType)
// Setup session management
connect( this, TQT_SIGNAL( restoreDocument(const KURL &, int) ), view, TQT_SLOT( restoreDocument(const KURL &, int)));
- connect( this, TQT_SIGNAL( saveDocumentRestoreInfo(KConfig*) ), view, TQT_SLOT( saveDocumentRestoreInfo(KConfig*)));
+ connect( this, TQT_SIGNAL( saveDocumentRestoreInfo(TDEConfig*) ), view, TQT_SLOT( saveDocumentRestoreInfo(TDEConfig*)));
setXMLFile( "kviewshell.rc" );
createGUI(view);
@@ -168,7 +168,7 @@ void KViewShell::readSettings()
resize(600, 300); // default size if the config file specifies no size
setAutoSaveSettings( "General" ); // apply mainwindow settings (size, toolbars, etc.)
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup("General");
recent->loadEntries(config, "Recent Files");
@@ -191,7 +191,7 @@ void KViewShell::readSettings()
void KViewShell::writeSettings()
{
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup( "General" );
recent->saveEntries(config, "Recent Files");
@@ -199,7 +199,7 @@ void KViewShell::writeSettings()
}
-void KViewShell::saveProperties(KConfig* config)
+void KViewShell::saveProperties(TDEConfig* config)
{
// the 'config' object points to the session managed
// config file. anything you write here will be available
@@ -208,7 +208,7 @@ void KViewShell::saveProperties(KConfig* config)
}
-void KViewShell::readProperties(KConfig* config)
+void KViewShell::readProperties(TDEConfig* config)
{
// the 'config' object points to the session managed
// config file. this function is automatically called whenever
diff --git a/kviewshell/kmultipage.cpp b/kviewshell/kmultipage.cpp
index dad18d22..4d544df9 100644
--- a/kviewshell/kmultipage.cpp
+++ b/kviewshell/kmultipage.cpp
@@ -172,8 +172,8 @@ void KMultiPage::slotSave()
return;
}
- KIO::Job *job = KIO::file_copy( KURL( m_file ), KURL( fileName ), 0600, true, false, true );
- connect( job, TQT_SIGNAL( result( KIO::Job * ) ), this, TQT_SLOT( slotIOJobFinished ( KIO::Job * ) ) );
+ TDEIO::Job *job = TDEIO::file_copy( KURL( m_file ), KURL( fileName ), 0600, true, false, true );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotIOJobFinished ( TDEIO::Job * ) ) );
return;
}
@@ -222,7 +222,7 @@ bool KMultiPage::closeURL()
return true;
}
-void KMultiPage::slotIOJobFinished ( KIO::Job *job )
+void KMultiPage::slotIOJobFinished ( TDEIO::Job *job )
{
if ( job->error() )
job->showErrorDialog( 0L );
@@ -629,7 +629,7 @@ void KMultiPage::handleLocalLink(const TQString &linkText)
gotoPage(anch);
else {
if (linkText[0] != '#' ) {
// We could in principle use KIO::Netaccess::run() here, but
// it is perhaps not a very good idea to allow a DVI-file to
// specify arbitrary commands, such as "rm -rvf /". Using
// the kfmclient seems to be MUCH safer.
@@ -629,7 +629,7 @@ void KMultiPage::handleLocalLink(const TQString &linkText)
else {
if (linkText[0] != '#' ) {
- // We could in principle use KIO::Netaccess::run() here, but
+ // We could in principle use TDEIO::Netaccess::run() here, but
// it is perhaps not a very good idea to allow a DVI-file to
// specify arbitrary commands, such as "rm -rvf /". Using
diff --git a/kviewshell/kviewshell.h b/kviewshell/kviewshell.h
index 3ea6ffef..064c4da1 100644
--- a/kviewshell/kviewshell.h
+++ b/kviewshell/kviewshell.h
@@ -44,7 +44,7 @@ protected slots:
signals:
void restoreDocument(const KURL &url, int page);
- void saveDocumentRestoreInfo(KConfig* config);
+ void saveDocumentRestoreInfo(TDEConfig* config);
protected:
void readSettings();
@@ -54,14 +54,14 @@ protected:
* This method is called when it is time for the app to save its
* properties for session management purposes.
*/
- void saveProperties(KConfig*);
+ void saveProperties(TDEConfig*);
/**
* This method is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- void readProperties(KConfig*);
+ void readProperties(TDEConfig*);
void checkActions();
@@ -54,14 +54,14 @@ protected:
/**
- * This method is called when this app is restored. The KConfig
+ * This method is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties